/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.cassandra.sidecar.config;

import io.vertx.core.http.HttpMethod;
import org.apache.cassandra.sidecar.common.server.utils.MillisecondBoundConfiguration;

/**
 * Encapsulates Schema Reporting configuration
 */
public interface SchemaReportingConfiguration extends PeriodicTaskConfiguration
{
    /**
     * An endpoint address for schema reporting; empty by default
     */
    String endpoint();

    /**
     * An HTTP verb to use when reporting schemata; {@code PUT} by default
     */
    HttpMethod method();

    /**
     * A number of times a schema report is retried in case of failure; {@code 3} by default
     */
    int maxRetries();

    /**
     * A delay before a schema report is retried in case of failure; one minute by default
     */
    MillisecondBoundConfiguration retryDelay();
}
